@@ -1,7 +1,5 @@
-# $Id: page.rb,v 1.1.1.1 2003/02/18 14:23:36 take Exp $
-# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
-# You can redistribute it and/or modify it under the terms of
-# the Ruby's licence.
+# $Id: page.rb,v 1.4.2.1 2005/05/17 08:09:54 fdiary Exp $
+# Copyright (C) 2002-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'cgi'
 
@@ -18,21 +16,26 @@ module Hiki
     def to_html
       tmpl = TemplateFile.new @template
       html = ''
-#      tmpl = TemplateFileWithCache[template]
+#      tmpl = TemplateFileWithCache[@template]
 #      tmpl.use_compiler = true
-#      tmpl.set_hint_by_sample_data(data)
+#      tmpl.set_hint_by_sample_data(@contents)
       tmpl.expand_attr = true
       tmpl.expand(html, @contents)
       html
     end
 
-    def page( plugin, last_modified )
+    def page( plugin )
+      $title = @contents[:title]
       @contents[:header]         = plugin.header_proc.sanitize
       @contents[:body_leave]     = plugin.body_leave_proc.sanitize
+      @contents[:footer]         = plugin.footer_proc.sanitize
+      
       html = to_html
       header = Hash::new
-      header['Last-Modified']    = CGI::rfc1123_date(last_modified) if last_modified
-      header['Content-Type']     = 'text/html'
+      if @contents[:last_modified] and /HEAD/i =~ @cgi.request_method
+	header['Last-Modified']    = CGI::rfc1123_date(@contents[:last_modified])
+      end
+      header['type']     = 'text/html'
       header['charset']          = $charset
       header['Content-Length']   = html.size.to_s
       header['Content-Language'] = $lang
